/*
 * The MIT License
 *
 * Copyright 2012 Xavi Miró.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.sf.jinterflex;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;

/**
 * The dynamic proxy handler for the object to be called via reflection using
 * jInterflex.
 *
 * @author Xavi Miró
 */
 class InstanceProxyHandler<T> implements InvocationHandler, IInstanceProxy {

    private final T realObj_;
    private final Class<T> realClass_;

    /**
     * Ctor.
     * @param realObj the real object to be called via jInterflex.
     * @param realClass the class of <code>realObject</code>.
     */
    public InstanceProxyHandler(T realObj, Class<T> realClass){

        realObj_ = realObj;
        realClass_ = realClass;
    }

    /**
     *
     */
    @Override
    public Object invoke(Object proxy, Method method, Object[] args)
    throws Throwable {

        Object res = null;
        Class<?> realClass = realObj_.getClass();
        String methodName = method.getName();
        Class<?> declClass = method.getDeclaringClass();
        res = ClassProxyHandler.invokeMethod(method, realObj_, realClass, args, null);

        return res;
    }

    /**
     * Returns the real object that will be accessed.
     * @return the real object.
     */
    public Object getRealObject() {

        return realObj_;
    }

    /**
     * Returns the real class that will be accessed.
     * @return the real class.
     */
    public Class<?> getRealClass() {

        return realClass_;
    }
}
