/*
 * The MIT License
 *
 * Copyright 2012 Xavi Miró.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package net.sf.jinterflex;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;

/**
 * Class returned when the creation of the proxy was not possible due to errors.
 * Each method invoked will throw the exception that caused that error.
 *
 * @author Xavi Miró
 */
class UnavailableProxyHandler implements InvocationHandler, IProxified {

    private final Exception exception_;

    /**
     *
     */
    public UnavailableProxyHandler(Exception exception) {
        
        exception_ = exception;
    }

    /**
     *
     */
    public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {

        throw exception_;
    }

    /**
     * Returns the exception that caused the problem.
     * @return the exception.
     */
    public Exception getException() {

        return exception_;
    }
}
